<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * Creates an array of product condition options
 *
 * @return array
 */
function product_condition_options( $option = false ) {
	$product_conditions = array(
		'default'					=> __( 'Select product condition...', 'product-condition' ),
		'acceptable'				=> __( 'Acceptable', 'product-condition' ),
		'brand-new'					=> __( 'Brand New', 'product-condition' ),
		'certified-pre-owned'		=> __( 'Certified Pre-Owned', 'product-condition' ),
		'damaged'					=> __( 'Damaged', 'product-condition' ),
		'for-parts'					=> __( 'For Parts', 'product-condition' ),
		'good'						=> __( 'Good', 'product-condition' ),
		'like-new'					=> __( 'Like New', 'product-condition' ),
		'manufacturer-refurbished'	=> __( 'Manufacturer Refurbished', 'product-condition' ),
		'new'						=> __( 'New', 'product-condition' ),
		'new-other'					=> __( 'New Other (see details)', 'product-condition' ),
		'new-with-box'				=> __( 'New With Box', 'product-condition' ),
		'new-with-defects'			=> __( 'New With Defects', 'product-condition' ),
		'new-with-tags'				=> __( 'New With Tags', 'product-condition' ),
		'new-without-box'			=> __( 'New Without Box', 'product-condition' ),
		'new-without-tags'			=> __( 'New Without Tags', 'product-condition' ),
		'pre-owned'					=> __( 'Pre-Owned', 'product-condition' ),
		'remanufactured'			=> __( 'Remanufactured', 'product-condition' ),
		'retread'					=> __( 'Retread', 'product-condition' ),
		'seller-refurbished'		=> __( 'Seller Refurbished', 'product-condition' ),
		'used'						=> __( 'Used', 'product-condition' ),
		'very-good'					=> __( 'Very Good', 'product-condition' ),
		'other'						=> __( 'Other', 'product-condition' ),
	);
	/**
	 * Filter allows for custom product conditions.
	 */
	$product_conditions = apply_filters( 'product_condition_options', $product_conditions );

	if ( $option ) {
		$return = array_key_exists( $option, $product_conditions ) ? $product_conditions[$option] : '';
	} else {
		$return = $product_conditions;
	}

	return $return;
}

/**
 * Selects the appropriate Schema OfferItemCondition value based on
 * the human readable condition that has been selected.
 *
 * @return string
 */
function product_condition_schema_OfferItemCondition( $condition ) {
	$schema = false;
	switch ( $condition ) {
		/**
		 * Indicate that the item is NewCondition.
		 * https://schema.org/NewCondition
		 */
		case 'brand-new':
		case 'new':
		case 'new-other':
		case 'new-with-box':
		case 'new-with-defects':
		case 'new-with-tags':
		case 'new-without-box':
		case 'new-without-tags':
			$schema = 'NewCondition';
			break;

		/**
		 * Indicate that the item is UsedCondition.
		 * https://schema.org/UsedCondition
		 */
		case 'acceptable':
		case 'certified-pre-owned':
		case 'good':
		case 'like-new':
		case 'pre-owned':
		case 'used':
		case 'very-good':
			$schema = 'UsedCondition';
			break;

		/**
		 * Indicate that the item is RefurbishedCondition.
		 * https://schema.org/RefurbishedCondition
		 */
		case 'manufacturer-refurbished':
		case 'remanufactured':
		case 'retread':
		case 'seller-refurbished':
			$schema = 'RefurbishedCondition';
			break;

		/**
		 * Indicate that the item is DamagedCondition.
		 * https://schema.org/DamagedCondition
		 */
		case 'damaged':
		case 'for-parts':
			$schema = 'DamagedCondition';
			break;

		/**
		 * No schema condition exists or an unknown "other" condition.
		 * Return false and do not add markup.
		 * product_condition_schema_markup() will not add a
		 * product condition if false is returned.
		 */
		default:
			$schema = false;
			break;
	}
	/**
	 * Filter allows for custom conditions to be
	 * categorized appropriately.
	 */
	return apply_filters( 'product_condition_schema_OfferItemCondition', $schema, $condition );
}

/**
 * Given the product id, return the appropriate product condition.
 * If no product condition is selected for the product, return the
 * default product condition.
 *
 * @param int $product_id The ID number of the product to be looked up.
 * @param int $category_id The ID number of the category to be looked up. Note: this is not currently supported, but is included for future use.
 *
 * @return string
 */
function product_condition_return_selected_condition( $product_id = false, $variation_id = false ) {
	// Retrieve the default condition that is set in the plugin settings
	$default_option = get_option( 'product_condition_default_condition' );
	// Retrieve the product condition that is set in the product settings
	$condition_option = get_post_meta( $product_id, 'product_condition_condition_option', true );
	// Set the $product_condition to either the $condition_option if set or the $default_option
	$product_condition = !( null === $condition_option || '' === $condition_option || 'default' === $condition_option ) ? $condition_option : $default_option;

	return $product_condition;
}
